@@ -41,7 +41,7 @@ class SearchPlugin : public QObject, public Akonadi::AbstractSearchPlugin
     Q_INTERFACES(Akonadi::AbstractSearchPlugin)
     Q_PLUGIN_METADATA(IID "org.kde.akonadi.SearchPlugin" FILE "akonadi_search_plugin.json")
 public:
-    QSet<qint64> search(const QString &query, const QVector<qint64> &collections, const QStringList &mimeTypes) Q_DECL_OVERRIDE;
+    QSet<qint64> search(const QString &query, const QVector<qint64> &collections, const QStringList &mimeTypes) override;
 private:
     Akonadi::Search::Query fromAkonadiQuery(const QString &akonadiQuery, const QList<qint64> &collections, const QStringList &mimeTypes);
 };
